#
# spec file for package atuin
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           atuin
Version:        12.0.0
Release:        bp155.1.7
Summary:        Magical shell history
License:        MIT
Group:          System/Console
URL:            https://github.com/ellie/atuin
Source0:        %{url}/archive/refs/tags/v%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        cargo_config
BuildRequires:  c++_compiler
BuildRequires:  c_compiler
BuildRequires:  cargo-packaging
BuildRequires:  rust+cargo >= 1.59

%description
Atuin replaces your existing shell history with a SQLite database, and records additional context for your commands.
Additionally, it provides optional and fully encrypted synchronisation of your history between machines, via an Atuin server.

%package bash-completion
Summary:        Bash completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package fish-completion
Summary:        Fish completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%prep
%autosetup -a1
mkdir .cargo
cp %{SOURCE2} .cargo/config

%build
%{cargo_build} --all-features

for shell in "zsh" "bash" "fish"
do
  ./target/release/%{name} gen-completions --shell "$shell" > target/%{name}."$shell"
done

%install
%{cargo_install}
install -D -m 0644 "target/%{name}.bash" "%{buildroot}/%{_datadir}/bash-completion/completions/%{name}"
install -D -m 0644 "target/%{name}.fish" "%{buildroot}/%{_datadir}/fish/vendor_completions.d/%{name}.fish"
install -D -m 0644 "target/%{name}.zsh" "%{buildroot}/%{_datadir}/zsh/site-functions/_%{name}"

%files
%license LICENSE
%doc README.md CHANGELOG.md src/shell
%{_bindir}/atuin

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%files fish-completion
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/%{name}.fish

%files zsh-completion
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_%{name}

%changelog
* Thu Nov 17 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Fix installation of shell completions.
- Add extra shell stuff in docs.
* Sat Nov 12 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to version 12.0.0:
  * Allow stateless commands to be run without config/database by @c-14 in #544
  * Clear RBUFFER when accepting output from atuin by @c-14 in #545
  * Add installer support for Termux by @laurentlbm in #540
  * Bump lukemathwalker/cargo-chef from latest-rust-1.63 to latest-rust-1.64.0 by @dependabot in #546
  * Add contributors command by @ellie in #550
  * Add style to config.toml and config.md by @xfzv in #552
  * Fix compatability with fish vi key bindings by @shreve in #541
  * add some error messages by @conradludgate in #510
  * update zh-CN docs by @helbing in #539
  * Bump debian from bullseye-20220822-slim to bullseye-20221004-slim by @dependabot in #551
  * Add automatic update checking by @ellie in #555
  * Bump sqlx from 0.5.13 to 0.6.2 by @dependabot in #536
  * Bump indicatif from 0.16.2 to 0.17.1 by @dependabot in #537
  * Bump rpassword from 6.0.1 to 7.0.0 by @dependabot in #530
  * Bump tui from 0.18.0 to 0.19.0 by @dependabot in #531
  * Bump rmp-serde from 1.1.0 to 1.1.1 by @dependabot in #557
  * Bump unicode-width from 0.1.9 to 0.1.10 by @dependabot in #535
  * rollup of 5 dependency commits by @conradludgate in #562
  * Add message begging for help lol turtle by @ellie in #569
  * upgrade clap by @conradludgate in #568
  * Configure reqwest to use native platform certs by @wpbrz in #574
  * Bump async-trait from 0.1.57 to 0.1.58 by @dependabot in #575
  * Never use HISTFILE for fish shell import by @patricksjackson in #573
  * Respect fish shell's builtin private mode by @patricksjackson in #577
  * Bump clap from 4.0.15 to 4.0.18 by @dependabot in #578
  * docs: add more details about date parsing in the stats command by @bvergnaud in #579
  * Make fuzzy search the default by @ellie in #591
  * Update server.md by @pevogam in #589
  * Exit with return code 1 when no results are found in atuin search command by @TymanWasTaken in #489
  * Update README.md with antigen instruction. by @DanielAtCosmicDNA in #549
  * Build ARM64 releases & update runners by @Absolucy in #593
  * Add local event log storage by @ellie in #390
  * fix #596: Avoid drawing a command section beyond the width of the list by @s0 in #597
  * Add setting for keeping typed query when exiting by @s0 in #451
  * Fix copy/paste artifact by @EricCrosson in #598
  * Release v12 by @ellie in #599
* Tue Oct 11 2022 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Add shell completion packages
* Thu Oct  6 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Set rust+cargo version at least 1.59.
* Thu Sep 29 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec of atuin version 11.0.0
